==> huaweicloudsdkiec-3.0.49-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/delete_security_group_rule_request.py <==
# coding: utf-8

import pprint
import re

import six





class DeleteSecurityGroupRuleRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'security_group_rule_id': 'str'
    }

    attribute_map = {
        'security_group_rule_id': 'security_group_rule_id'
    }

    def __init__(self, security_group_rule_id=None):
        """DeleteSecurityGroupRuleRequest - a model defined in huaweicloud sdk"""
        
        

        self._security_group_rule_id = None
        self.discriminator = None

        self.security_group_rule_id = security_group_rule_id

    @property
    def security_group_rule_id(self):
        """Gets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID。

        :return: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :rtype: str
        """
        return self._security_group_rule_id

    @security_group_rule_id.setter
    def security_group_rule_id(self, security_group_rule_id):
        """Sets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID。

        :param security_group_rule_id: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :type: str
        """
        self._security_group_rule_id = security_group_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiec-3.0.51-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/delete_security_group_rule_request.py <==
# coding: utf-8

import re
import six





class DeleteSecurityGroupRuleRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'security_group_rule_id': 'str'
    }

    attribute_map = {
        'security_group_rule_id': 'security_group_rule_id'
    }

    def __init__(self, security_group_rule_id=None):
        """DeleteSecurityGroupRuleRequest - a model defined in huaweicloud sdk"""
        
        

        self._security_group_rule_id = None
        self.discriminator = None

        self.security_group_rule_id = security_group_rule_id

    @property
    def security_group_rule_id(self):
        """Gets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID。

        :return: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :rtype: str
        """
        return self._security_group_rule_id

    @security_group_rule_id.setter
    def security_group_rule_id(self, security_group_rule_id):
        """Sets the security_group_rule_id of this DeleteSecurityGroupRuleRequest.

        安全组规则ID。

        :param security_group_rule_id: The security_group_rule_id of this DeleteSecurityGroupRuleRequest.
        :type: str
        """
        self._security_group_rule_id = security_group_rule_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
